FormBuilder class

Inheritance

Constructors

FormBuilder({required Map<String, dynamic> initialData, required int index, InputDecoration? textfieldDecoration, double? textFieldWidth, String? multipleimage, String? dropdownImage, String? checkboxImage, String? dateImage, String? textImage, String? remarkImage, String? submitButtonText, bool showIcon = false, required Function onSubmit, bool showIndex = true, BoxDecoration? submitButtonDecoration, double? submitButtonWidth = 0.5, TextStyle? submitTextDecoration, String? title, String? description, TextStyle? descriptionStyle, TextStyle? titleStyle, CrossAxisAlignment widgetCrossAxisAlignment = CrossAxisAlignment.start, TextStyle? titleTextDecoration, TextStyle? descriptionTextDecoration})

Properties

checkboxImage → String?
final
dateImage → String?
final
description → String?
final
descriptionStyle → TextStyle?
final
descriptionTextDecoration → TextStyle?
final
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
final
initialData → Map<String, dynamic>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
multipleimage → String?
final
onSubmit → Function
final
remarkImage → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showIcon → bool
final
showIndex → bool
final
submitButtonDecoration → BoxDecoration?
final
submitButtonText → String?
final
submitButtonWidth → double?
final
submitTextDecoration → TextStyle?
final
textfieldDecoration → InputDecoration?
final
textFieldWidth → double?
final
textImage → String?
final
title → String?
final
titleStyle → TextStyle?
final
titleTextDecoration → TextStyle?
final
widgetCrossAxisAlignment → CrossAxisAlignment
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _FormBuilderState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited